@                                                                                                 @
@                                 MOC7F1R.PRG                                         @

@  Simulate a dataset for monte carlo estimation in our revision  @

@   Firms need not sell in France, forget about keeping fixed costs @

@   Based on moc7f12.prg @

@  Calibrate aggregates, including # and exports of firms with negative French sales @

@  use new data from Francis (8/20/2007)                                             @
@  save fixed costs so we can calculate productivity                                 @
@    Impose rho = -1                                                  @
@                                                                     @
@    Use only the French data, no Feenstra data or mkt size data      @
@        Back out the sigmaEn based on French entry                   @
@                                                                      @
@     (uses GAUSS dataset feature to store results)                     @
@                                                                                                   @
@         Simulate a firm dataset based on Melitz-Chaney              @
@                                                                                                     @
@                   Make exporters large in France                           @
@                                                                                  @
@             Try scaling up the size of the world                                  @ 

@                                                                                                   @
@                       (based on simekk8.prg)                                       @
@                                                                                                     @
@                remember that firm's sales are big                             @
@                                                                                                    @                     
@                                                                                                     @
@                                    8/21/2009                                                @


NEW;
cls;
OUTPUT FILE = c:\kortum\research\EKK\revision\monte\moc7f1r.out RESET;


nfirm = 230423;   @ number of firms to simulate (or j's) @


@ Initialize parameters @
@  The model has 5 parameters @

 
thetatil = 2;                                     @ theta/(sigma-1) @
sigma_a = 2;                         @ std. dev. of sales shock @
sigma_h = .4133;                     @ std. dev. of entry shock @
rho_ah =  -0.99;                     @ correlation of sales and entry shock @
lamdatil = .5;                             @ lambda/(sigma-1) @

thetatil = 2.46; 
sigma_a = 1.69; 
sigma_h = .34;
rho_ah =  -0.65; 
lamdatil= .91; 


parmvec = thetatil|sigma_a|sigma_h|rho_ah|lamdatil;


" ";
" ******************** ";
" PARAMETER VALUES ";
"thetatil = " thetatil;
"sigma_a = " sigma_a;
"sigma_h = " sigma_h;
"rho_ah = " rho_ah; 
"lamdatil = " lamdatil;
" ";
"nfirm = " nfirm;

" ******************** ";




@ ************** @
@                      @
@  Get the data @
@                       @
@  *************  @

ncnty = 113;
ncntyfr = 34;   @ position of France @

vcnty = seqa(1,1,ncnty);

frvec = zeros(ncnty,1);
frvec[ncntyfr] = 1;

format /rd 16,4;

@ French data by country (in $ millions) @


load ekkcnty[113,12] = c:\kortum\research\EKK\chi0708\paysd.raw;

xnf = ekkcnty[.,1]; 
sun1 = ekkcnty[.,2];


@ Data on Firms with negative French Sales (in $ millions) @

load ekkneg[113,2] = c:\kortum\research\EKK\chi0708\paysneg.raw;
sunneg = ekkneg[.,1];
xnfneg = ekkneg[.,2];


sun1 = sun1 + sunneg;
xnf = xnf + xnfneg;

xbarnf = xnf./sun1;



@ ******************************** @
@                                                  @
@   Stage 2 of simulation:            @
@  Calculate price level function @
@                                                  @
@  *******************************  @


ithetat = 1/thetatil;
gamparm = 1-ithetat;

lamstar = lamdatil/(thetatil+lamdatil-1);

okappa1 = exp((sigma_a^2 + sigma_h^2*(thetatil-1)^2+2*rho_ah*sigma_a*sigma_h*(thetatil-1))/2);

kappa2 = exp((sigma_h*thetatil)^2/2);

kappa1 = okappa1*(lamstar/gamparm);

sigmaen = (kappa2/kappa1)*xbarnf;  @ sigma times country specific fixed cost from actual data @



biglam = (xnf./kappa1)./sigmaen;


@ ******************************** @
@                                                  @
@   Stage 3 of simulation:            @
@  Calculate firm-level behavior  @
@                                                  @
@  *******************************  @


@ create dataset for monte carlo draws @

create firmdat = firmdata with x,ncnty,8;
create probdat = probdata with x,1,8;

@ Loop through creating one simulated French firm each time @


j = 1;
do while j <= nfirm;

     
@  ***************************************** @
@                                                                 @
@  Step a: mkt size and fixed cost shocks @
@                                                                  @
@  ****************************************** @

@  random fixed cost and random size of a good, alpha @


   araw = rndn(1,ncnty); 
   hraw = rndn(1,ncnty); 
 
   leta = sigma_h*hraw;
   lalpha = sigma_a*sqrt((1-rho_ah^2))*araw + sigma_a*rho_ah*hraw;



@  ********************************************* @
@                                                                      @
@  Calculate ubar's and uf's     @
@                                                                       @
@  ********************************************* @   

   @ *** step 1: calculate cost draws @
   
    @ draw the u for France @
   
      v = rndu(1,1); 

      vf = v;  @ potential French firm @
      
     lubarm = thetatil*leta + ln(biglam');
     lubar = (maxc(lubarm'))';
     ubar=exp(lubar);

     uf = vf*ubar;

     pubar = ubar;

@  ************************************************* @
@                                                                            @
@  Steps d and e: French firm entry and sales     @
@                                                                            @
@  ************************************************* @   

    luf = ln(uf);

    hurdle1 = (lubarm .>= luf);     @ the entry hurdles @

   smat = hurdle1;  @ entry vector,  need to pass hurdles @

   uf = exp(luf);
  
   urel = exp(luf - lubarm);
   nu = 1-urel^(lamdatil/thetatil);
   nu = smat.*nu + (1-smat);

   lxmat = ln(nu) + lalpha + ithetat*ln(biglam') + ln(sigmaen') - ithetat*luf; 

   xmat = smat.*exp(lxmat);

  y = writer(firmdat,xmat);
  y = writer(probdat,pubar);



j = j+1;
endo;

firmdat = close(firmdat);
probdat = close(probdat);





