pause on

* CONSUMPTION GOODS

* The new INDUSTRY-level data from Francis
* July 14th, 2009


clear

* I included France in country.dta
use country
* French data already combine Belgium and Luxembourg
drop if uncode==442
sort paysnum
save country2, replace


* thousands of French Francs

use paysd_cons
rename paynum paysnum
rename sun sun86

gen p95rat86 = p95ratd 
gen q3rat86 = q3ratd 
gen medrat86 = medratd
gen q1rat86 = q1ratd 

gen meanfr86 = meanfrd/(1000*6.93) 
gen p95fr86 = p95frd/(1000*6.93) 
gen q3fr86 = q3frd/(1000*6.93) 
gen medfr86 = medfrd/(1000*6.93)
gen q1fr86 = q1frd/(1000*6.93)
gen p5fr86 = p5frd/(1000*6.93)
gen meanpay86 = meanpayd/(1000*6.93)
gen p95pay86 = p95payd/(1000*6.93)
gen q3pay86 = q3payd/(1000*6.93)
gen medpay86 = medpayd/(1000*6.93)
gen q1pay86 = q1payd/(1000*6.93)
gen p5pay86 = p5payd/(1000*6.93)
keep paysnum sun86 p95rat86 q3rat86 medrat86 q1rat86 meanfr86 p95fr86 q3fr86 medfr86 q1fr86 p5fr86 meanpay86 p95pay86 q3pay86 medpay86 q1pay86 p5pay86
sort paysnum
merge paysnum using country2
keep if _merge==3
drop _merge
sort paysnum
save gtrade, replace

use aerdata
sort paysnum
merge paysnum using gtrade
drop _merge
sort paysnum

gen xnf86 = sun86*meanpay86

gen lsun86 = ln(sun86)

*  1986 absorption is already in $ millions
rename tabsorp absorp86

gen labsorp86 = ln(absorp86)

gen ffshare86 = xnf86/absorp86

gen lffshare86 = ln(ffshare86)

gen sun86ff = sun86/ffshare86 


* 1986 regression with French firm exports and new data
*regress lsun86 lffshare86 labsorp86

* 1986 regression to go along with Fig 1b
gen nlsun86 = lsun86 - lffshare86
regress nlsun86 labsorp86, robust


gen absorp86b = absorp86/1000

scatter sun86 absorp86b, mlabel(ccode) msize(small) mlabsize(small) xscale(log) yscale(log) /*
 */ xlabel(.1 1 10 100 1000 10000) ylabel(10 100 1000 10000 100000, angle(horizontal)) /*
    */ ytitle("# firms selling in market") xtitle("market size ($ billions)") /*
       */ title("Panel A: Entry of Firms") saving(fig1a,replace)

pause
 
scatter sun86ff absorp86b, mlabel(ccode) msize(small) mlabsize(small) xscale(log) yscale(log) /*
 */ xlabel(.1 1 10 100 1000 10000) ylabel(1000 10000 100000 1000000 5000000, angle(horizontal)) /*
    */ ytitle("entry normalized by French market share") xtitle("market size ($ billions)") /*
       */ title("Panel B: Normalized Entry") saving(fig1b,replace)

pause


scatter p95pay86 q3pay86 medpay86 q1pay86 absorp86b, legend(off) mlabel(ccode) msize(small small small small) /*
  */   msymbol(smcircle smx smtriangle smdiamond) mlabsize(small) xscale(log) yscale(log) /*
 */ xlabel(.1 1 10 100 1000 10000) ylabel(.001 .01 .1 1 10, angle(horizontal)) /*
    */ ytitle("percentiles (25, 50, 75, 95) by market ($ millions)") xtitle("market size ($ billions)") /*
       */ title("Panel C: Sales Percentiles") saving(fig1c,replace)


pause

gr combine fig1a.gph fig1b.gph fig1c.gph, iscale(.5) col(1) xsize(6.5) ysize(9) xcommon title("Figure 1: Consumption Goods Producers")





gen lp95pay86 = ln(p95pay86)
gen lq3pay86 = ln(q3pay86)
gen lmedpay86 = ln(medpay86)
gen lq1pay86 = ln(q1pay86)
regress lp95pay86 labsorp86
regress lq3pay86 labsorp86
regress lmedpay86 labsorp86
regress lq1pay86 labsorp86




* Figs 2 are sales distributions, calculated elsewhere
 
    
gen negsun86 = -sun86 
sort negsun86
gen sunrank = _n
   

pause

scatter meanfr86 sun86, mlabel(ccode) msize(small) mlabsize(small) xscale(log) yscale(log) /*
 */ xlabel(20 100 1000 10000 100000 500000) ylabel(1 10 100 1000, angle(horizontal)) /*
    */ ytitle("average sales in France ($ millions)") xtitle("# firms selling in the market") /*
       */ title("Panel C: Sales and # Selling to a Market") saving(fig3c,replace)


gen lmeanfr86 = ln(meanfr86)
regress lmeanfr86 lsun86

regress lmeanfr86 lsun86 if paysnum > 1


pause

scatter p95fr86 q3fr86 medfr86 q1fr86 sun86, legend(off) mlabel(ccode) msize(small small small small)  /*
  */   msymbol(smcircle smx smtriangle smdiamond) mlabsize(small) xscale(log) yscale(log) /*
 */ xlabel(20 100 1000 10000 100000 500000) ylabel(.1 1 10 100 1000 10000, angle(horizontal)) /*
    */ ytitle("percentiles (25, 50, 75, 95) in France ($ millions)") xtitle("# firms selling in the market") /*
       */ title("Panel D: Distribution of Sales and Market Entry") saving(fig3d,replace)


gen lp95fr86 = ln(p95fr86)
gen lq3fr86 = ln(q3fr86)
gen lmedfr86 = ln(medfr86)
gen lq1fr86 = ln(q1fr86)
regress lp95fr86 lsun86
regress lq3fr86 lsun86
regress lmedfr86 lsun86
regress lq1fr86 lsun86


* mean sales in france is 1.572638
gen temp2 = medrat86/(meanpay86/1.572638)

gen ltemp2 = ln(temp2)
gen lsun86new = ln(sun86)

regress ltemp2 lsun86new

gen lq3rat86 = ln(q3rat86/meanpay86)
gen lmedrat86 = ln(medrat86/meanpay86)
regress lq3rat86 lsun86
regress lmedrat86 lsun86

gen medrat86n = medrat86/(meanpay86/1.572638)
gen q1rat86n = q1rat86/(meanpay86/1.572638)
gen q3rat86n = q3rat86/(meanpay86/1.572638)
gen p95rat86n = p95rat86/(meanpay86/1.572638)


pause

scatter p95rat86n medrat86n sun86 if paysnum>1 , legend(off) mlabel(ccode) msize(small small) /*
  */   msymbol(smcircle smtriangle ) mlabsize(small) xscale(log) yscale(log) /*
 */ xlabel(10 100 1000 10000 100000) ylabel(.001 .01 .1 1) /*
    */ ytitle("percentiles (50, 95) of normalized export intensity") xtitle("# firms selling in the market") /*
       */ title("Figure 4: Consumption Goods Producers") xsize(5.5) ysize(4)


pause

clear

* 1986 data
use statsexplusd_cons
rename nmventfrd nmventfr86

rename mventfrd mventfr86
rename p5ventfrd p5ventfr86
rename q1ventfrd q1ventfr86
rename medventfrd medventfr86
rename q3ventfrd q3ventfr86
rename p95ventfrd p95ventfr86
rename mm7d mprod86
replace mventfr86= mventfr86/(1000*6.93)
replace p5ventfr86= p5ventfr86/(1000*6.93)
replace q1ventfr86= q1ventfr86/(1000*6.93)
replace medventfr86= medventfr86/(1000*6.93)
replace q3ventfr86= q3ventfr86/(1000*6.93)
replace p95ventfr86= p95ventfr86/(1000*6.93)
replace mprod86= mprod86/(1000*6.93)
sort itir


gen lmventfr86 = ln(mventfr86)
gen lnmventfr86 = ln(nmventfr86)
regress lmventfr86 lnmventfr86


pause

scatter mventfr86 itir, xscale(log) yscale(log) /*
 */ xlabel(1 2 4 8 16 32 64 128) ylabel(1 10 100 1000 10000, angle(horizontal)) /*
    */ ytitle("average sale in France ($ millions)") xtitle("minimum number of markets penetrated") /*
       */ title("Panel A: Sales and Markets Penetrated") saving(fig3a,replace)



pause

scatter mventfr86 nmventfr86, mlabel(itir) msize(small) mlabsize(vsmall) xscale(log) yscale(log) /*
 */ xlabel(1 10 100 1000 10000 100000 500000) ylabel(1 10 100 1000 10000, angle(horizontal)) /*
    */ ytitle("average sale in France ($ millions)") xtitle("# firms selling to k or more markets") /*
       */ title("Panel B: Sales and # Penetrating Multiple Markets") saving(fig3b,replace)


pause

gr combine fig3a.gph fig3b.gph fig3c.gph fig3d.gph, iscale(.5) xsize(9) ysize(6.5) title("Figure 3: Consumption Goods Producers")











