@                             CFAGG11.PRG                               @

@         ************ fixed delta2 ******************************* @

@                                                                   @
@              Solves for the ge of the EKK extended Model        @
@                                                                   @            
@                  Use 114 country dataset for 1986 (including ROW as last one)  @
@                                                                        @
@                  revised 11/14/2008   @
@     Revision to introduce country specific alphas                       @
@                            Corrected Delta2 and price index                                                    @


new;
cls;
OUTPUT FILE = c:\kortum\research\EKK\chi1108\cfagg11.out RESET;

ncnty = 114;
cntynum = seqa(1,1,114);
ncntyfr = 34;
  
vfactor = .2;  @ wage iteration term @

maxit = 10000;  @ maximum iterations for wage or price mappings @

@ tolerances for wage and price iteration @

wtol = .000001;
ptol = .000001;

@ parameters from EKK estimation @
  
thetatil = 2.4629; 
sigma_a = 1.6878; 
sigma_h = 0.3397;
rho_ah =  -0.6477; 
lamdatil= 0.9086; 

@ externally set parameters @

@ calibrate mygamm based on mfg. value added as a share of mfg. gross production (from UNIDO) @
vashare = .3612913;

mbar = 1.5059;
mysigma = mbar/(mbar - 1);
mytheta = thetatil*(mysigma - 1);
betavar = mbar*vashare - 1/mytheta;

sigtheta = (1/(mysigma - 1)) - (1/mytheta);


" ";
" ********************** ";
" parameter values ";
" thetatil " thetatil;
" lamdatil " lamdatil;
" mysigma " mysigma;
" mytheta " mytheta;
" vashare " vashare;
" betavar " betavar;
" ********************** ";
" ";

@ list of country names @
let cnty = "AFGHAN" "ALBANIA" "ALGERIA" "ANGOLA" "ARGENTIN" "AUSTRALI" "AUSTRIA" "BANGLADE" "BELGIUML"
"BENIN" "BOLIVIA" "BRAZIL" "BULGARIA" "BURKINAF" "BURUNDI" "CAMEROON" "CANADA" "CENAFREP" 
"CHAD" "CHILE" "CHINA" "COLOMBIA" "COSTAR" "COTEDI" "CUBA" "CZECH" "DENMARK" 
"DOMREP" "ECUADOR" "EGYPT" "ELSALV" "ETHIOPIA" "FINLAND" "FRANCE" "GERMANYE" "GERMANYW" 
"GHANA" "GREECE" "GUATEM" "HONDURAS" "HONGKONG" "HUNGARY" "INDIA" "INDONES" "IRAN" "IRAQ" "IRELAND" "ISRAEL" 
"ITALY" "JAMAICA" "JAPAN" "JORDAN" "KENYA" "KOREAS" "KUWAIT" "LIBERIA" "LIBYA" "MADAGASC" "MALAWI" 
"MALAYSIA" "MALI" "MAURITAN" "MAURITIU" "MEXICO" "MOROCCO" "MOZAMBIQ" "NEPAL" "NETHERL" "NEWZEAL" 
"NICARAG" "NIGER" "NIGERIA" "NORWAY" "OMAN" "PAKISTAN" "PANAMA" "PAPNEWGU" "PARAGUAY" "PERU" 
"PHILIPP" "PORTUGAL" "ROMANIA" "RWANDA" "SAUDI" "SENEGAL" "SIERRAL" "SINGAPO" "SOMALIA" 
"SOUTHAFR" "SPAIN" "SRILANKA" "SUDAN" "SWEDEN" "SWITZER" "SYRIA" "TAIWAN" "TANZANIA" 
"THAILAND" "TOGO" "TRINTOB" "TUNISIA" "TURKEY" "UGANDA" "UK" "US" "URUGUAY" 
"USSR" "VENEZUEL" "VIETNAM" "YUGOSLAV" "ZAIRE" "ZAMBIA" "ZIMBABWE" "ZZROW";

let cntynrow = "AFGHAN" "ALBANIA" "ALGERIA" "ANGOLA" "ARGENTIN" "AUSTRALI" "AUSTRIA" "BANGLADE" "BELGIUML"
"BENIN" "BOLIVIA" "BRAZIL" "BULGARIA" "BURKINAF" "BURUNDI" "CAMEROON" "CANADA" "CENAFREP" 
"CHAD" "CHILE" "CHINA" "COLOMBIA" "COSTAR" "COTEDI" "CUBA" "CZECH" "DENMARK" 
"DOMREP" "ECUADOR" "EGYPT" "ELSALV" "ETHIOPIA" "FINLAND" "FRANCE" "GERMANYE" "GERMANYW" 
"GHANA" "GREECE" "GUATEM" "HONDURAS" "HONGKONG" "HUNGARY" "INDIA" "INDONES" "IRAN" "IRAQ" "IRELAND" "ISRAEL" 
"ITALY" "JAMAICA" "JAPAN" "JORDAN" "KENYA" "KOREAS" "KUWAIT" "LIBERIA" "LIBYA" "MADAGASC" "MALAWI" 
"MALAYSIA" "MALI" "MAURITAN" "MAURITIU" "MEXICO" "MOROCCO" "MOZAMBIQ" "NEPAL" "NETHERL" "NEWZEAL" 
"NICARAG" "NIGER" "NIGERIA" "NORWAY" "OMAN" "PAKISTAN" "PANAMA" "PAPNEWGU" "PARAGUAY" "PERU" 
"PHILIPP" "PORTUGAL" "ROMANIA" "RWANDA" "SAUDI" "SENEGAL" "SIERRAL" "SINGAPO" "SOMALIA" 
"SOUTHAFR" "SPAIN" "SRILANKA" "SUDAN" "SWEDEN" "SWITZER" "SYRIA" "TAIWAN" "TANZANIA" 
"THAILAND" "TOGO" "TRINTOB" "TUNISIA" "TURKEY" "UGANDA" "UK" "US" "URUGUAY" 
"USSR" "VENEZUEL" "VIETNAM" "YUGOSLAV" "ZAIRE" "ZAMBIA" "ZIMBABWE";


@ manufacturing trade data from wtdata86b.do in $1000 @

load xbilat[12996,1] = c:\kortum\research\EKK\chi0708\cfactual\xnidata.raw; 
xbilat = reshape(xbilat,ncnty,ncnty);   @ want exporters as columns @

@ adjust to US $ millions @

xbilat = xbilat/1000;

@ replace diagonals with zeros @

xbilat = diagrv(xbilat,zeros(ncnty,1));

@ total mfg. imports and exports (for 114 countries) @

imprt = sumc(xbilat');
exprt = sumc(xbilat);

@ load 1986 trade surplus and GDP in 1000's of US $ from UN @

load surpdata[ncnty,1] = c:\kortum\research\EKK\chi0708\cfactual\surpdata.raw;
load gdpdata[ncnty,1] = c:\kortum\research\EKK\chi0708\cfactual\gdpdata.raw;

 @ adjust to US $ millions @

tsurp = surpdata/1000;
gdp = gdpdata/1000;

@ spread the deficit of the world across all countries @

tsurpold = tsurp;
gweight = gdp/sumc(gdp);
ttsurp = sumc(tsurp);
tsurp = tsurp - gweight*ttsurp;

@ deficit in manufacturing @

defm = imprt - exprt;

" ";
" cnty exprt imprt defm ";
call printfmt((cnty~exprt~imprt~defm),(0~1~1~1));
"  ";

xgdp = gdp - tsurp;     @ aggregate final spending @

"  cnty gdp xgdp tsurp ";
call printfmt((cnty~gdp~xgdp~tsurp),(0~1~1~1));
"  ";

@ manufacturing absorption @

load absdata[ncnty,1] = c:\kortum\research\EKK\chi0708\cfactual\absdata.raw;

@ adjust to US $ millions @

absorp = absdata/1000;

ym = absorp - defm;

"  absorp, ym, defm  ";
call printfmt((cnty~absorp~ym~defm),(0~1~1~1));
"  ";

@ implied home sales @

xnn = ym - exprt;

xnimat = diagrv(xbilat,xnn);


shrhome = xnn./absorp;
shexprt = exprt./ym;

" ";
" cnty ym exprt shexprt";
call printfmt((cnty~ym~exprt~shexprt),(0~1~1~1));
" ";

deft = -tsurp;   @ total deficit in goods and services @

@ create some trade statistics @

" ";
" cnty xnn imprt ";
call printfmt((cnty~xnn~imprt),(0~1~1));
" ";

xm0 = xnn + imprt;
pimat = xnimat./xm0;

" ";
" cnty xm absorp";
" xm and absorp should be the same ";
call printfmt((cnty~xm0~absorp),(0~1~1));
" ";

@ create country specific mftr expenditure shares (alphas) from expenditure and mftr absorption @

alphavec = (xm0 - (1 - betavar)*(1-(1/mysigma))*ym)./xgdp;

@ some statitics behind alphavec @
xmshare = xm0./xgdp;
defmshare = defm./xgdp;
gdpshare = gdp./xgdp;

"  ";
"  cnty, xmshare, defmshare, gdpshare";
call printfmt((cnty~xmshare~defmshare~gdpshare),(0~1~1~1));
" ";

" cnty ym xgdp alphavec";
call printfmt((cnty~ym~xgdp~alphavec),(0~1~1~1));
" ";

@ coefficients for calculations below @

delta1 = ((mysigma-1)/mysigma)*(1-betavar);
delta2 = 1/thetatil;

coef = delta2/(1+betavar*(mysigma-1));
coefgdp = ones(114,1) - coef*alphavec;

@ create denominator terms @
denomvec = ones(114,1) + betavar*(mysigma - 1) - delta2*alphavec;
badmat = denomvec*(1/denomvec');

@ factor income @

yl = coefgdp.*gdp - coef*(alphavec.*deft) + coef*defm;

@
" gdp, xm, and factor income yl ";
cnty~gdp~xm0~yl;
call printfmt((cnty~gdp~xm0~yl),(0~1~1~1));
"  ";
@ 

yl0 = yl; @ keep track of original factor income @

xnimat0 = xnimat;  @ keep track of original trade matrix @




@ ***********************************************************************@
@ counterfactuals: (i) changes in the T_i's, (ii) changes in d_ni's,     @
@ (iii) changes in F_i's, and (iv) changes in deficits.                  @
@  The first three are expressed as a ratio of                           @  
@  counterfactual to the current value.                                  @
@ ***********************************************************************@



@ First we do (i), (ii), and (iii) to perturb pimat @

that = ones(1,ncnty);   @ T's form the columns @ 




fixhat = ones(1,ncnty);


fixred = 1.1;

fixhat = fhat/fixred;





dniratio = ones(ncnty,ncnty);

@ cost reduction means a number greater than one @

costred = 1.1;
costred = 1;




dniratio = dniratio/costred;
dniratio = diagrv(dniratio,ones(ncnty,1));

hat = (dniratio^(-mytheta)).*that;
temp = xnimat0.*hat;

pimat0 = temp./sumc(temp');

@ (iii) counterfactual deficits @

@ Here no change @

defmc = defm;        @   counterfactual deficit in mfg @  
deftc = deft;        @ counterfactual total deficit in goods and services @

@ initialize vectors of ex-post wage and price factors @

wf0 = ones(ncnty,1);
pf0 = ones(ncnty,1);
xmf0 = ones(ncnty,1);


pf00 = ones(ncnty,1);
lpf00 = ln(pf00);

pimat1 = 0;
yl1 = 0;

@ mapping from one log price change vector to another given wf0 @

proc lpmap(lpf);
   local lpf0,lpf1,lwf0,lwfpf0,elwfpf0,xmprime,lxmf0;

   lpf0 = lpf;
   lwf0 = ln(wf0);
   xmprime = (1/denomvec).*(mysigma*alphavec.*(yl0.*wf0 + deftc) + (denomvec - mysigma).*defmc);
   xmf0 = xmprime./xm0;
   lxmf0 = ln(xmf0);
   lwfpf0 = betavar*lwf0 + (1-betavar)*lpf0;
   elwfpf0 = exp(-mytheta*lwfpf0);
   lpf1 = -ln(((hat.*pimat)*elwfpf0))/mytheta + sigtheta*lwf0 + sigtheta*ln(fixhat) - sigtheta*lxmf0;
   retp(lpf1);
endp;


@ calculate new bilateral trade shares @

proc pimatnew(wf,pf);
   local wftb,pftb,wfpftb,xnimat1;

   wftb = wf^(-mytheta*betavar);
   pftb = pf^(-mytheta*(1-betavar));
   wfpftb = wftb.*pftb;
   xnimat1 = pimat0.*wfpftb'; 
   pimat1 = xnimat1./sumc(xnimat1');

   retp(pimat1);
endp;

@ mapping from one wage change vector to another, given pf0 @

proc wmap(wf);
   local zw,tw;
        
   pimat1 = pimatnew(wf,pf0);
   yl1 = wf.*yl0;
   zw = ((badmat.*(pimat1'))*(alphavec.*(yl1 + deftc) - delta1*defmc - (delta2/mysigma)*(alphavec.*defmc)) - (alphavec.*(yl1 + deftc) - defmc))./wf;
   tw = wf.*(1+vfactor*zw./yl0);
   retp(tw);
endp;



@ ******************************************* @
@ iteration on wages and prices @
@ ******************************************* @

wfmax = 2*wtol;
i = 0;

do while i <= maxit and wfmax > wtol;

   @ first calculate prices consistent with wf0 @

   pfmax = 2*ptol;
   j = 0; 

   do while j <= maxit and pfmax > ptol;

      @ iterate to find log price @
      lpf0 = lpmap(lpf00);
      pfdev = abs(lpf0 - lpf00);
      pfmax = maxc(pfdev);
      lpf00 = lpf0;
   @   " j = " j; @
      j = j+1;
      if j==maxit;
         " *****************************";
         " error: prices did not converge ";
         "******************************";
       endif;
   endo;

   pf0 = exp(lpf0);
   wf1 = wmap(wf0);

   wfdev = abs(ln(wf1./wf0));
   wfmax = maxc(wfdev);
   wf0 = wf1;
   @ " i = " i; @
   @ " cnty wf0 pf0 "; @
   @ cntynum~wf0~pf0; @
   i = i+1;
   if i==maxit;
         " *****************************";
         " error:  wages did not converge ";
         "******************************";
    endif;
endo;

@ save wf0 = wf0; @

wf1 = wmap(wf0);
pf1 = exp(lpmap(ln(pf0)));


" ";
" factor change in wage in last 2 iteration steps (wf) and in mfg prices (pf) ";
" cnty~wf0~wf1~pf0 ";
call printfmt((cnty~wf0~wf1~pf0),(0~1~1~1));
" ";

" ";
" mfg prices (pf) in last 2 iteration steps";
" cnty~pf0~pf1 ";
call printfmt((cnty~pf0~pf1),(0~1~1));
" ";

@ the change in the price level and its components @

pfb = xmf0^(-sigtheta);
pfc = wf1^(sigtheta);
pfa = pf1./(pfb.*pfc);

" ";
" change in price and change in price due to bigfee (pfa), xm (pfb) entry cost (pfc) ";
" cnty pf1 pfa pfb";
call printfmt((cnty~pf1~pfa~pfb),(0~1~1~1));
"  ";
" cnty pf1 pfb pfc";
call printfmt((cnty~pf1~pfb~pfc),(0~1~1~1));

yl2 = ((((badmat.*(pimat1'))*(alphavec.*(yl1 + deftc) - delta1*defmc - (delta2/mysigma)*(alphavec.*defmc))) + defmc)./alphavec) - deftc;


" ";
" initial factor income (yl0) and counterfactual factor income calculated in 2 ways (yl1 and yl2) ";
" cnty yl0 yl1 yl2 ";
call printfmt((cnty~yl0~yl1~yl2),(0~1~1~1));

@ calculate new GDP @

gdpnew = (yl1 + coef*(alphavec.*deftc) - coef*defmc)./coefgdp;

@ calculate change in real wage @
mftrpp = wf1./pf1;
realwfa = mftrpp^alphavec;

" ";
" new wage, price index, and real wage ";
" cnty wf1 pf1 realwfa  ";
call printfmt((cnty~wf1~pf1~realwfa),(0~1~1~1));

" ";
" new wage, price index, and manufacturing purchasing power";
" cnty wf1 pf1 mftrpp";
call printfmt((cnty~wf1~pf1~mftrpp),(0~1~1~1));

pinn0 = diag(pimat);
pinn1 = diag(pimat1);

xm1 = (mysigma*(alphavec.*(gdpnew + deftc)) - (mysigma-1)*(1-betavar)*defmc)/(1+betavar*(mysigma-1));
xnimat1 = pimat1.*xm1;

"  ";
"old and new factor income";
call printfmt((cnty~yl0~yl1),(0~1~1));

"  ";
"old and new gdp";
call printfmt((cnty~gdp~gdpnew),(0~1~1));

"  ";
"old and new xnimat (French only) ";
call printfmt((cnty~xnimat0[.,ncntyfr]~xnimat1[.,ncntyfr]),(0~1~1));

@ save new French sales and number of exporters @


xnfhat = xnimat1[.,ncntyfr]./xnimat0[.,ncntyfr];
nnfhat = xnfhat./(wf1.*fixhat);

"  ";
"  change in French sales and in French sellers ";
"  ";

call printfmt((cnty~xnfhat~nnfhat),(0~1~1));

xmhat = xm1./xm0;
pinfhat = pimat1[.,ncntyfr]./pimat[.,ncntyfr];

"  ";
"  change in French sales decomposed into market share and market size ";
"  ";

call printfmt((cnty~xnfhat~pinfhat~xmhat),(0~1~1~1));

imprt0 = imprt;
pimnf0 = xnimat0[.,ncntyfr]./imprt0;

xnimatt1 = diagrv(xnimat1,zeros(ncnty,1));
imprt1 = sumc(xnimatt1');

pimnf1 = xnimat1[.,ncntyfr]./imprt1;
pimnfhat = pimnf1./pimnf0;
imprthat = imprt1./imprt0;


"  ";
"  change in French sales decomposed into France's share of imports and imports ";
"  ";

call printfmt((cnty~xnfhat~pimnfhat~imprthat),(0~1~1~1));


"  ";
"  change in French sales, change in imports, level of home share ";
"  ";

call printfmt((cnty~xnfhat~imprthat~shrhome),(0~1~1~1));

"  ";
"  change in French sales, change in wage there, level of home share ";
"  ";

call printfmt((cnty~xnfhat~wf1~shrhome),(0~1~1~1));


temp1 = (1.01)^(mytheta*shrhome);
temp2 = (1.01*wf1)^(mytheta*shrhome);


"  ";
"  change in French sales, temp1, temp2 ";
"  ";

call printfmt((cnty~xnfhat~temp1~temp2),(0~1~1~1));

ols(0,ln(xnfhat),ln(temp2));

ols(0,ln(temp2),ln(xnfhat));


wphat = wf1~pf1;

save xnfhat = xnfhat;
save nnfhat = nnfhat;
save wphat = wphat;

" ";
absorp0 = sumc(xnimat0[ncntyfr,.]');
absorp1 = sumc(xnimat1[ncntyfr,.]');

xnn0 = xnimat0[ncntyfr,ncntyfr];
xnn1 = xnimat1[ncntyfr,ncntyfr];

import0 = absorp0 - xnn0;
import1 = absorp1 - xnn1;

export0 = sumc(xnimat0[.,ncntyfr]) - xnn0;
export1 = sumc(xnimat1[.,ncntyfr]) - xnn1;

impshr0 = import0/absorp0;
impshr1 = import1/absorp1;

expshr0 = export0/absorp0;
expshr1 = export1/absorp1;

" ";
" baseline shares: ";
"    exports/absorption = " expshr0;
"    imports/absorption = " impshr0;
" ";
" counterfactual shares: ";
"    exports/absorption = " expshr1;
"    imports/absorption = " impshr1;



xnimatfr0 = xnimat0[1:113,ncntyfr];
xnimatfr1 = xnimat1[1:113,ncntyfr]/pf1[ncntyfr];

" ";
totfr0 = sumc(xnimatfr0);
totfrd0 = xnimatfr0[ncntyfr];
totfrx0 = totfr0 - totfrd0;
" total sales of French firms, totfr0 " totfr0;
" total domestic sales of French firms, totfrd0 " totfrd0;
" total exports of French firms, totfrx0 " totfrx0;
" ";
" *** The following are relative to the manufacturing price level *** ";
totfr1 = sumc(xnimatfr1);
totfrd1 = xnimatfr1[ncntyfr];
totfrx1 = totfr1 - totfrd1;
" counterfactual, totfr1 " totfr1;
" counterfactual, totfrd1 " totfrd1;
" counterfactual, totfrx1 " totfrx1;
" ";
" change, totfr1-totfr0 " (totfr1 - totfr0);
" change, totfrd1-totfrd0 " (totfrd1 - totfrd0);
" change, totfrx1-totfrx0 " (totfrx1 - totfrx0);
" ";
call printfmt((cntynrow~xnimatfr0~xnimatfr1),(0~1~1));



