@                                                                                                 @
@                                 ENTDEC3.PRG                                         @
@          Entry decomposition                                                         @
@    Keep track of fixed costs actually paid   @
@                                                                     @
@        Back out the sigmaEn based on French entry                   @
@                                                                      @
@     (uses GAUSS dataset feature to store results)                     @
@                                                                                                   @
@         Simulate a firm dataset based on Melitz-Chaney              @
@                                                                                                     @
@                   Make exporters large in France                           @
@                                                                                                    @
@                       (based on simekk8.prg)                                       @
@                                                                                                     @
@                remember that firm's sales are big                             @
@                                                                                                    @                     
@                                                                                                     @
@                                    11/8/2008                                                @


NEW;
cls;
OUTPUT FILE = c:\kortum\research\EKK\chi1108\entdec3.out RESET;

nfirm = 230000;   @ number of firms to simulate (or j's) @


@ Initialize parameters @
@  The model has 4 parameters @

 
thetatil = 2;                                     @ theta/(sigma-1) @
sigma_a = 2;                         @ std. dev. of log alphatilde (random size of a good) @
zeta = 1.2;                         @ epsilontilde = alphatilde^(zeta) @
lamdatil = .5;                             @ lambda/(sigma-1) @

sigma_h = (zeta-1)*sigma_a;


thetatil = 2.4630; 
sigma_a = 1.6880;
sigma_h = 0.33397;
rho_ah = -0.6477; 
lamdatil= 0.9086; 

" ";
" ******************** ";
" PARAMETER VALUES ";
"thetatil = " thetatil;
"sigma_a = " sigma_a;
"sigma_h = " sigma_h;
"rho = " rho_ah;
"lamdatil = " lamdatil;
" ";
"nfirm = " nfirm;

" ******************** ";


@ ************** @
@                      @
@  Get the data @
@                       @
@  *************  @

ncnty = 113;
ncntyfr = 34;   @ position of France @

vcnty = seqa(1,1,ncnty);

frvec = zeros(ncnty,1);
frvec[ncntyfr] = 1;

format /rd 16,4;

@ list of country names @
let cnty = "AFGHAN" "ALBANIA" "ALGERIA" "ANGOLA" "ARGENTIN" "AUSTRALI" "AUSTRIA" "BANGLADE" "BELGIUML"
"BENIN" "BOLIVIA" "BRAZIL" "BULGARIA" "BURKINAF" "BURUNDI" "CAMEROON" "CANADA" "CENAFREP" 
"CHAD" "CHILE" "CHINA" "COLOMBIA" "COSTAR" "COTEDI" "CUBA" "CZECH" "DENMARK" 
"DOMREP" "ECUADOR" "EGYPT" "ELSALV" "ETHIOPIA" "FINLAND" "FRANCE" "GERMANYE" "GERMANYW" 
"GHANA" "GREECE" "GUATEM" "HONDURAS" "HONGKONG" "HUNGARY" "INDIA" "INDONES" "IRAN" "IRAQ" "IRELAND" "ISRAEL" 
"ITALY" "JAMAICA" "JAPAN" "JORDAN" "KENYA" "KOREAS" "KUWAIT" "LIBERIA" "LIBYA" "MADAGASC" "MALAWI" 
"MALAYSIA" "MALI" "MAURITAN" "MAURITIU" "MEXICO" "MOROCCO" "MOZAMBIQ" "NEPAL" "NETHERL" "NEWZEAL" 
"NICARAG" "NIGER" "NIGERIA" "NORWAY" "OMAN" "PAKISTAN" "PANAMA" "PAPNEWGU" "PARAGUAY" "PERU" 
"PHILIPP" "PORTUGAL" "ROMANIA" "RWANDA" "SAUDI" "SENEGAL" "SIERRAL" "SINGAPO" "SOMALIA" 
"SOUTHAFR" "SPAIN" "SRILANKA" "SUDAN" "SWEDEN" "SWITZER" "SYRIA" "TAIWAN" "TANZANIA" 
"THAILAND" "TOGO" "TRINTOB" "TUNISIA" "TURKEY" "UGANDA" "UK" "US" "URUGUAY" 
"USSR" "VENEZUEL" "VIETNAM" "YUGOSLAV" "ZAIRE" "ZAMBIA" "ZIMBABWE";


@ French data by country (in $ millions) @

load ekkcnty[113,13] = c:\kortum\research\EKK\chi0108\cnty86.raw;

xnf = ekkcnty[.,1]; 
sun = ekkcnty[.,2];
xbarnf = xnf./sun;


@ ******************************** @
@                                                  @
@   Stage 2 of simulation:            @
@  Calculate price level function @
@                                                  @
@  *******************************  @


ithetat = 1/thetatil;
gamparm = 1-ithetat;

lamstar = lamdatil/(thetatil+lamdatil-1);

okappa1 = exp((sigma_a^2 + sigma_h^2*(thetatil-1)^2+2*rho_ah*sigma_a*sigma_h*(thetatil-1))/2);

kappa2 = exp((sigma_h*thetatil)^2/2);

kappa1 = okappa1*(lamstar/gamparm);

sigmaen = (kappa2/kappa1)*xbarnf;  @ sigma times country specific fixed cost @

biglam = (xnf./kappa1)./sigmaen;


@ Loop through creating one simulated French firm each time @

msmat2 = zeros(nfirm,ncnty);
mzeros = zeros(nfirm,ncnty);
vpubar = zeros(nfirm,1);

j = 1;
do while j <= nfirm;

     
@  ***************************************** @
@                                                                 @
@  Step a: mkt size and fixed cost shocks @
@                                                                  @
@  ****************************************** @

@  random fixed cost and random size of a good, alpha @

   araw = rndn(1,ncnty); 
   hraw = rndn(1,ncnty); 
   
   leta = sigma_h*hraw;
   lalpha = sigma_a*sqrt((1-rho_ah^2))*araw + sigma_a*rho_ah*hraw;


@  ********************************************* @
@                                                                      @
@  Calculate ubar's and uf's     @
@                                                                       @
@  ********************************************* @   

   @ *** step 1: calculate cost draws @
   
    @ draw the u for France @
   
      v = rndu(1,1); 

      vf = v;  @ potential French firm @
      
     lubar = thetatil*leta + ln(biglam');
     lubarf = lubar[1,ncntyfr];
     ubarf = exp(lubarf);

     uf = vf*ubarf;

     pubar = ubarf;

     vpubar[j]=pubar;


@  ************************************************* @
@                                                                            @
@  Steps d and e: French firm entry and sales     @
@                                                                            @
@  ************************************************* @   

    luf = ln(uf);

   @  ************************************************* @
   @                                                    @
   @     Calculate probability of entry, by country     @
   @                                                    @
   @  ************************************************* @   

   @ Correct for over sampling of high cost firms @

   temp = (luf - ln(biglam'))/(thetatil*sigma_h);
  
   smat = cdfnc(temp);  @ probability of each firm entering each country @   

   smat[1,ncntyfr] = 1;   @ By construction all sell in France @

   msmat2[j,.] = smat;

j = j+1;
endo;


pubarm=sumc(vpubar);

meansimp = sun./sun[ncntyfr];
varsimp = meansimp.*(1-meansimp);


varcon2 = sumc(vpubar.*(msmat2.*(1-msmat2)))/pubarm;



" ";
" ************************* ";
" I propose the last column of the following table ";
" ************************* ";

rsquare = 1 - (varcon2./varsimp);

" ";
" country, varcon2, varsimp, rsquare ";
call printfmt((cnty~varcon2~varsimp~rsquare),(0~1~1~1));


rsquare = delif(rsquare,frvec);

mrsquare = meanc(rsquare);
stdrsquare = stdc(rsquare);

" ";
" mrsquare ";
mrsquare;
" ";
" stdrsquare ";
stdrsquare;



