@                                                                                                 @
@                                 SALDEC3C.PRG                                         @
@          Sales decomposition                                                         @
@    Keep track of fixed costs actually paid                                     @                                                                     
@        Back out the sigmaEn based on French entry                   @
@                                                                      @
@     (uses GAUSS dataset feature to store results)                     @
@                                                                                                   @
@         Simulate a firm dataset based on Melitz-Chaney              @
@                                                                                                     @
@                   Make exporters large in France                           @
@                                                                                                    @
@                       (based on simekk8.prg)                                       @
@                                                                                                     @
@                remember that firms' sales are big                             @
@                                                                                                    @                     
@                                                                                                     @
@                                    11/8/2008                                                @


NEW;
cls;

OUTPUT FILE = c:\kortum\research\EKK\chi1108\saldec3c.out RESET;

nfirm = 230000;   @ number of firms to simulate (or j's) @

@ Estimates from first stage (gmmsav1.out saved as gmmsav1_newboot1.prg) @
thetatil = 2.4629; 
sigma_a = 1.6878; 
sigma_h = 0.3397; 
rho_ah = -0.6477; 
lamdatil = 0.9086; 

" ";
" ******************** ";
" PARAMETER VALUES ";
"thetatil = " thetatil;
"sigma_a = " sigma_a;
"sigma_h = " sigma_h;
"rho_ah = " rho_ah;
"lamdatil = " lamdatil;
" ";
"nfirm = " nfirm;

" ******************** ";


@ ************** @
@                      @
@  Get the data @
@                       @
@  *************  @

ncnty = 113;
ncntyfr = 34;   @ position of France @

vcnty = seqa(1,1,ncnty);

frvec = zeros(ncnty,1);
frvec[ncntyfr] = 1;

format /rd 16,4;

@ list of country names @
let cnty = "AFGHAN" "ALBANIA" "ALGERIA" "ANGOLA" "ARGENTIN" "AUSTRALI" "AUSTRIA" "BANGLADE" "BELGIUML"
"BENIN" "BOLIVIA" "BRAZIL" "BULGARIA" "BURKINAF" "BURUNDI" "CAMEROON" "CANADA" "CENAFREP" 
"CHAD" "CHILE" "CHINA" "COLOMBIA" "COSTAR" "COTEDI" "CUBA" "CZECH" "DENMARK" 
"DOMREP" "ECUADOR" "EGYPT" "ELSALV" "ETHIOPIA" "FINLAND" "FRANCE" "GERMANYE" "GERMANYW" 
"GHANA" "GREECE" "GUATEM" "HONDURAS" "HONGKONG" "HUNGARY" "INDIA" "INDONES" "IRAN" "IRAQ" "IRELAND" "ISRAEL" 
"ITALY" "JAMAICA" "JAPAN" "JORDAN" "KENYA" "KOREAS" "KUWAIT" "LIBERIA" "LIBYA" "MADAGASC" "MALAWI" 
"MALAYSIA" "MALI" "MAURITAN" "MAURITIU" "MEXICO" "MOROCCO" "MOZAMBIQ" "NEPAL" "NETHERL" "NEWZEAL" 
"NICARAG" "NIGER" "NIGERIA" "NORWAY" "OMAN" "PAKISTAN" "PANAMA" "PAPNEWGU" "PARAGUAY" "PERU" 
"PHILIPP" "PORTUGAL" "ROMANIA" "RWANDA" "SAUDI" "SENEGAL" "SIERRAL" "SINGAPO" "SOMALIA" 
"SOUTHAFR" "SPAIN" "SRILANKA" "SUDAN" "SWEDEN" "SWITZER" "SYRIA" "TAIWAN" "TANZANIA" 
"THAILAND" "TOGO" "TRINTOB" "TUNISIA" "TURKEY" "UGANDA" "UK" "US" "URUGUAY" 
"USSR" "VENEZUEL" "VIETNAM" "YUGOSLAV" "ZAIRE" "ZAMBIA" "ZIMBABWE";


@ French data by country (in $ millions) @

load ekkcnty[113,13] = c:\kortum\research\EKK\chi0108\cnty86.raw;

xnf = ekkcnty[.,1]; 
sun = ekkcnty[.,2];
xbarnf = xnf./sun;


@ ******************************** @
@                                                  @
@   Stage 2 of simulation:            @
@  Calculate price level function @
@                                                  @
@  *******************************  @


ithetat = 1/thetatil;
gamparm = 1-ithetat;

lamstar = lamdatil/(thetatil+lamdatil-1);

okappa1 = exp((sigma_a^2 + sigma_h^2*(thetatil-1)^2+2*rho_ah*sigma_a*sigma_h*(thetatil-1))/2);

kappa2 = exp((sigma_h*thetatil)^2/2);

kappa1 = okappa1*(lamstar/gamparm);

sigmaen = (kappa2/kappa1)*xbarnf;  @ sigma times country specific fixed cost @

biglam = (xnf./kappa1)./sigmaen;



@ Loop through creating one simulated French firm each time @

mpubar = zeros(nfirm,ncnty); @ need country specific pubar @
mlx2mat = zeros(nfirm,ncnty);

j = 1;
do while j <= nfirm;

     
@  ***************************************** @
@                                                                 @
@  Step a: mkt size and fixed cost shocks @
@                                                                  @
@  ****************************************** @

@  random fixed cost and random size of a good, alpha @

   araw = rndn(1,ncnty); 
   hraw = rndn(1,ncnty); 
 
   leta = sigma_h*hraw;
   lalpha = sigma_a*sqrt((1-rho_ah^2))*araw + sigma_a*rho_ah*hraw;


@  ********************************************* @
@                                                                      @
@  Calculate ubar's and uf's     @
@                                                                       @
@  ********************************************* @   

   @ *** step 1: calculate cost draws @
   
    @ draw the u for Firm @
   
      v = rndu(1,1); 
    
     lubar = thetatil*leta + ln(biglam'); @ hurdle for each country  n @
     lubarmax = maxindc(lubar');             @ I just put this in to see if it matters @
     lubarf = lubar[1,ncntyfr];           @ hurdel for France @

     mlubar = lubar|(lubarf*ones(1,ncnty));
     lubarfn = minc(mlubar)';             @ hurdle for selling in both n and France @

     ubarfn = exp(lubarfn);

     un = v*ubarfn;  @ guarantee entry in each market, and France as well @

     mpubar[j,.]=ubarfn;   @ importance weight, differs by country in this program since we condition on entry @

@  ************************************************* @
@                                                                            @
@  Steps d and e: French firm entry and sales     @
@                                                                            @
@  ************************************************* @   

   lun = ln(un);

   urel = exp(lun - lubar);  @ arkolakis term just depends on the hurdle in country n @

   nu = 1-urel^(lamdatil/thetatil);
  
   lx2mat = ln(nu) - ithetat*lun; 
   mlx2mat[j,.] = lx2mat;

  
j = j+1;
endo;

mpubar = mpubar./sumc(mpubar)';


mean2x = sumc((mpubar.*mlx2mat));
var2x = sumc((mpubar.*(mlx2mat-mean2x')^2));

load varux = varux;
rat2 = var2x./varux;

" ";
" country, rat2";
call printfmt((cnty~rat2),(0~1));

" ";

mrat2 = meanc(rat2);
srat2 = stdc(rat2);

" ";
" mean rat2 " mrat2;
" std rat2 " srat2;
