pause on
* Use balls and bins data to graph export distributions by market
*   May, 2008

clear
set memory 100m

* I included France in country.dta
use country
* French data already combine Belgium and Luxembourg
* and no French observations in binsballs
drop if uncode==442
drop if uncode==250
rename paysnum paynum
sort paynum
save country2, replace
clear

use aerdata
rename paysnum paynum
drop if paynum == 1
keep paynum ccode
sort paynum
save aerdata2, replace
clear

use binsballsfr
gen ccode = "FRA"
gen country = "FRANCE"
gen paynum = 1
drop siren
rename ventfrd vfted
egen total = sum(vfted)
keep vfted paynum ccode country total
save frsales, replace
clear


use binsballs
sort paynum
merge paynum using country2
drop _merge
sort paynum
merge paynum using aerdata2

gen vfted = sumvfted - sumvftedp

keep vfted paynum ccode country total

append using frsales

egen rankit = rank(vfted), by(paynum)
egen sun = count(vfted), by(paynum)
gen mvfted = total/sun
gen rvfted = vfted/mvfted

gen myrank = sun - rankit + 1/2
gen gabaix = myrank/sun

gen lrvfted = ln(rvfted)
gen lgabaix = ln(gabaix)

regress lrvfted lgabaix if ccode == "FRA" & gabaix <= .01, robust

regress lrvfted lgabaix if ccode == "BEL" & gabaix <= .01, robust

regress lrvfted lgabaix if ccode == "IRE" & gabaix <= .01, robust

regress lrvfted lgabaix if ccode == "USA" & gabaix <= .01, robust

*scatter rvfted gabaix if ccode == "FRA", msize(small) xscale(log) yscale(log) /*
 */ xlabel(.00001 .0001 .001 .01 .1 1) ylabel(.001 .01 .1 1 10 100 1000, angle(horizontal)) /*
    */ ytitle("exports relative to mean") xtitle("fraction of firms exporting more") /*
       */ title("Figure 2a: Distribution of French Exports to France")

pause

*scatter rvfted gabaix if ccode == "IRE", msize(small) xscale(log) yscale(log) /*
 */ xlabel(.0001 .001 .01 .1 1) ylabel(.001 .01 .1 1 10 100 1000, angle(horizontal)) /*
    */ ytitle("exports relative to mean") xtitle("fraction of firms exporting more") /*
       */ title("Figure 2b: Distribution of French Exports to Ireland")

*pause

*scatter rvfted gabaix if ccode == "USA", msize(small) xscale(log) yscale(log) /*
 */ xlabel(.0001 .001 .01 .1 1) ylabel(.001 .01 .1 1 10 100 1000, angle(horizontal)) /*
    */ ytitle("exports relative to mean") xtitle("fraction of firms exporting more") /*
       */ title("Figure 2c: Distribution of French Exports to the United States")

keep if ccode == "BEL" | ccode == "IRE" | ccode == "USA" | ccode == "FRA" 


scatter rvfted gabaix, by(country, title("Figure 2: Sales Distributions of French Firms")) msize(small) xscale(log) yscale(log) /*
 */ xlabel(.00001 .0001 .001 .01 .1 1) ylabel(.001 .01 .1 1 10 100 1000, angle(horizontal)) /*
    */ ytitle("sales in market relative to mean") xtitle("fraction of firms selling at least that much") xsize(6.5) ysize(5) saving(fig2,asis replace)





